@@ -52,7 +52,7 @@ except ImportError:
 
 
 __all__ = ["tabulate", "tabulate_formats", "simple_separated_format"]
-__version__ = "0.8.3"
+__version__ = "0.8.5"
 
 
 # minimum extra space in headers
@@ -189,7 +189,7 @@ def _latex_line_begin_tabular(colwidths, colaligns, booktabs=False):
     alignment = { "left": "l", "right": "r", "center": "c", "decimal": "r" }
     tabular_columns_fmt = "".join([alignment.get(a, "l") for a in colaligns])
     return "\n".join(["\\begin{tabular}{" + tabular_columns_fmt + "}",
-                      "\\toprule" if booktabs else "\hline"])
+                      "\\toprule" if booktabs else "\\hline"])
 
 LATEX_ESCAPE_RULES = {r"&": r"\&", r"%": r"\%", r"$": r"\$", r"#": r"\#",
                       r"_": r"\_", r"^": r"\^{}", r"{": r"\{", r"}": r"\}",
@@ -1456,7 +1456,7 @@ def _main():
     Usage: tabulate [options] [FILE ...]
 
     Pretty-print tabular data.
-    See also https://bitbucket.org/astanin/python-tabulate
+    See also https://github.com/astanin/python-tabulate
 
     FILE                      a filename of the file with tabular data;
                               if "-" or missing, read data from stdin.
